==> 0.1.2%2B14.tar.gz: lib/etc/utility.dart <==
part of viltage;

class Utility {
  static render(List<List<Entity>> entities, List<List<SpanElement>> charArray) {
    for(int i = 0; i < entities.length; i++) {
      for(int j = 0; j < entities[i].length; j++) {
        entities[i][j].render(charArray);
      }
    }
 }
  
  static draw(ParagraphElement pe, List<List<SpanElement>> charArray) {
    List<SpanElement> se = new List<SpanElement>();
    for(int i = 0; i < charArray.length; i++) {
      for(int j = 0; j < charArray[0].length; j++) {
        se.add(charArray[i][j]);
      }
      SpanElement endLineElement = new SpanElement();
      endLineElement.setInnerHtml("</br>");
      se.add(endLineElement);
    }
    for(int i = 0; i < pe.children.length; i++) {
      if(pe.children[i] != se.first) {
        pe.children[i] = se.first;
        se.remove(se.first);
      }
    }
  }
  
  static update(List<List<Entity>> entities, double delta) {
    for(int i = 0; i < entities.length; i++) {
      for(int j = 0; j < entities[i].length; j++) {
        entities[i][j].update(delta);
      }
    }
  }
  
  static bool identical(List<List<SpanElement>> charArray, List<List<SpanElement>> charArray2) {
    for(int i = 0; i < charArray.length; i++) {
      for(int j = 0; j < charArray[i].length; j++) {
        if(charArray[i][j] != charArray2[i][j]) return false;
      }
    }
    return true;
  }
  
  static void merge(List<List<SpanElement>> charArray, List<List<SpanElement>> charArray2) {
    for(int i = 0; i < charArray.length; i++) {
      for(int j = 0; j < charArray[i].length; j++) {
        charArray2[i][j] = charArray[i][j];
      }
    }
  }
}

==> 0.2.0%2B14.tar.gz: lib/etc/utility.dart <==
part of viltage;

class Utility {
  static render(List<List<Entity>> entities, List<List<CharNode>> charArray) {
    for(int i = 0; i < entities.length; i++) {
      for(int j = 0; j < entities[i].length; j++) {
        entities[i][j].render(charArray);
      }
    }
 }
  
  static draw(CanvasRenderingContext2D ctx, int offX, int offY, List<List<CharNode>> charArray) {
    for(int i = 0; i < charArray.length; i++) {
      for(int j = 0; j < charArray[0].length; j++) {
        ctx.fillStyle = charArray[i][j].backgroundColor;
        ctx.fillRect(((j-.5)*offX).toInt(), ((i-.5)*offY).toInt(), ((j+.5)*offX).toInt(), ((i+.5)*offY).toInt());
        
        ctx.fillStyle = charArray[i][j].color;
        ctx.fillText(charArray[i][j].char, j*offX, (i+1)*offY);
      }
    }
  }
  
  static update(List<List<Entity>> entities, double delta) {
    for(int i = 0; i < entities.length; i++) {
      for(int j = 0; j < entities[i].length; j++) {
        entities[i][j].update(delta);
      }
    }
  }
  
  static bool identical(List<List<SpanElement>> charArray, List<List<SpanElement>> charArray2) {
    for(int i = 0; i < charArray.length; i++) {
      for(int j = 0; j < charArray[i].length; j++) {
        if(charArray[i][j] != charArray2[i][j]) return false;
      }
    }
    return true;
  }
  
  static void merge(List<List<SpanElement>> charArray, List<List<SpanElement>> charArray2) {
    for(int i = 0; i < charArray.length; i++) {
      for(int j = 0; j < charArray[i].length; j++) {
        charArray2[i][j] = charArray[i][j];
      }
    }
  }
}
